#[non_exhaustive]pub enum Error {
}Expand description
All errors that can be returned by this crate.
The variants fall into two categories:
- Rust-side conversion errors (
NulByte,Utf8): problems converting data before or after FFI calls. - C library status codes (all other variants): direct mappings of the
bicycl_status_tenum returned by the C API. Unknown: a status code not recognised by this version of the crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NulByte(NulError)
Utf8(Utf8Error)
NullPtr
The C library returned BICYCL_ERR_NULL_PTR, meaning the caller
passed a null pointer into the C API. This should not occur under
normal use of the safe Rust wrappers.
InvalidArgument
AllocationFailed
Internal
BufferTooSmall
Parse
InvalidState
VerifyFailed
ProtocolAbort
Core
Paillier
JoyeLibert
ClHsmqk
ClHsm2k
Ecdsa
TwoPartyEcdsa
ClThreshold
ClDlog
ThresholdEcdsa
Unknown(i32)